/*
 * @Company: hugeInfo
 * @Author: ldh
 * @Date: 2022-07-04 16:43:55
 * @LastEditTime: 2023-04-27 16:18:49
 * @LastEditors: lwh
 * @Version: 1.0.0
 * @Description: 纠纷登记modal入口
 */
import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import { useNavigate } from 'react-router-dom';
import './index.less';
import MyModal from '../MyModal';
import { Row, Col, Button } from 'antd';
import { registerChooseModal_1, registerChooseModal_2, registerChooseModal_3, registerChooseModal_4 } from '../../assets/images/icon';

const RegisterChooseModal = ({ visible = false }) => {
  let navigate = useNavigate();

  const [myModalVisible, setMyModalVisible] = useState(false);

  const [type, setType] = useState();

  const dataArr = [
    {
      title: '常规登记',
      subtitle: '适合登记和上传完整纠纷信息与案件材料',
      img: registerChooseModal_2,
      url: '/mediate/casePerfection',
    },
    {
      title: '快速登记',
      subtitle: '适合临时登记或需要马上开展调解工作',
      img: registerChooseModal_1,
      url: '/mediate/register',
    },
    // 白云区多元化平台功能下线-liyj
    // {
    // 	title: '系列案登记',
    // 	subtitle: '适合多方申请人或被申请人的系列案登记',
    // 	img: registerChooseModal_3,
    // 	url: '3',
    // },
  ];

  function handleClick(url) {
    if (url === '3') {
      setType(url);
    } else {
      setMyModalVisible(false);
      navigate(url);
    }
  }

  useEffect(() => {
    if (!!visible) {
      setMyModalVisible(true);
      setType();
    }
  }, [visible]);

  return (
    <MyModal
      visible={myModalVisible}
      onCancel={() => setMyModalVisible(false)}
      width={604}
      footer={
        type === '3'
          ? [
            <Button type="primary" onClick={() => navigate('/mediate/registerList')}>
              去草稿箱复制
            </Button>,
            <Button onClick={() => setType()}>关闭</Button>,
          ]
          : true
      }
      centered
    >
      {type === '3' ? (
        <div className="registerChooseModal-copyItem">
          <img src={registerChooseModal_4} alt="" />
          <div className="registerChooseModal-copyItem-content">复制「草稿箱」中的案件后 点击生成系列案按钮</div>
        </div>
      ) : (
        <Row gutter={[16, 16]}>
          {dataArr.map((x) => (
            <Col span={12} key={x.url}>
              <div className="registerChooseModal-item">
                <div>
                  <h4>{x.title}</h4>
                  <div className="registerChooseModal-subtitle">{x.subtitle}</div>
                  <Button className="public-mainBtn" onClick={() => handleClick(x.url)}>
                    立即登记
                  </Button>
                </div>
                <img className="registerChooseModal-img" src={x.img} alt="" />
              </div>
            </Col>
          ))}
        </Row>
      )}
    </MyModal>
  );
};

RegisterChooseModal.propTypes = {
  visible: PropTypes.any,
};

export default RegisterChooseModal;
